@@ -116,8 +116,9 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         """
         out, err = self._run_iscsi_session()
         if err:
-            LOG.warning("iscsiadm stderr output when getting sessions: %s",
-                        err)
+            LOG.warning("Couldn't find iscsi sessions because "
+                        "iscsiadm err: %s", err)
+            return []
 
         # Parse and clean the output from iscsiadm, which is in the form of:
         # transport_name: [session_id] ip_address:port,tpgt iqn node_type
@@ -835,12 +836,10 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         :type ignore_errors: bool
         """
         return self._cleanup_connection(connection_properties, force=force,
-                                        ignore_errors=ignore_errors,
-                                        device_info=device_info)
+                                        ignore_errors=ignore_errors)
 
     def _cleanup_connection(self, connection_properties, ips_iqns_luns=None,
-                            force=False, ignore_errors=False,
-                            device_info=None):
+                            force=False, ignore_errors=False):
         """Cleans up connection flushing and removing devices and multipath.
 
         :param connection_properties: The dictionary that describes all
@@ -856,7 +855,6 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         :param ignore_errors: When force is True, this will decide whether to
                               ignore errors or raise an exception once finished
                               the operation.  Default is False.
-        :param device_info: Attached device information.
         :type ignore_errors: bool
         """
         exc = exception.ExceptionChainer()
@@ -873,14 +871,9 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         remove_devices = set()
         for remove, __ in devices_map.values():
             remove_devices.update(remove)
-
-        path_used = self._linuxscsi.get_dev_path(connection_properties,
-                                                 device_info)
-        was_multipath = (path_used.startswith('/dev/dm-') or
-                         'mpath' in path_used)
-        multipath_name = self._linuxscsi.remove_connection(
-            remove_devices, self.use_multipath, force, exc,
-            path_used, was_multipath)
+        multipath_name = self._linuxscsi.remove_connection(remove_devices,
+                                                           self.use_multipath,
+                                                           force, exc)
 
         # Disconnect sessions and remove nodes that are left without devices
         disconnect = [conn for conn, (__, keep) in devices_map.items()
@@ -1030,7 +1023,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
             for s in sessions:
                 # Found our session, return session_id
                 if (s[0] in self.VALID_SESSIONS_PREFIX and
-                        portal.lower() == s[2].lower() and s[4] == target_iqn):
+                        portal == s[2] and s[4] == target_iqn):
                     return s[1], manual_scan
 
             try:
@@ -1071,7 +1064,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
 
     def _run_iscsi_session(self):
         (out, err) = self._run_iscsiadm_bare(('-m', 'session'),
-                                             check_exit_code=[0, 21, 255])
+                                             check_exit_code=[0, 1, 21, 255])
         LOG.debug("iscsi session list stdout=%(out)s stderr=%(err)s",
                   {'out': out, 'err': err})
         return (out, err)
