@@ -82,6 +82,8 @@ class LVM(executor.Executor):
                                   'LVM_SYSTEM_DIR=' + lvm_sys_dir]
 
         if create_vg and physical_volumes is not None:
+            self.pv_list = physical_volumes
+
             try:
                 self._create_vg(physical_volumes)
             except putils.ProcessExecutionError as err:
@@ -461,7 +463,7 @@ class LVM(executor.Executor):
                 if not lv['size'][-1].isdigit():
                     lvsize = lvsize[:-1]
                 if lv['name'] == self.vg_thin_pool:
-                    self.vg_thin_pool_size = float(lvsize)
+                    self.vg_thin_pool_size = lvsize
                     tpfs = self._get_thin_pool_free_space(self.vg_name,
                                                           self.vg_thin_pool)
                     self.vg_thin_pool_free_space = tpfs
